@@ -41,8 +41,6 @@
 
 #define KDECORATIONS2_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 #if defined(KDECORATIONS2_NO_DEPRECATED)
 #  undef KDECORATIONS2_DEPRECATED
 #  define KDECORATIONS2_DEPRECATED_EXPORT KDECORATIONS2_EXPORT
@@ -63,7 +61,7 @@
 #define KDECORATIONS2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECORATIONS2_NO_DEPRECATED
-#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b03
+#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b06
 #endif
 #ifdef KDECORATIONS2_NO_DEPRECATED_WARNINGS
 #  define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0
@@ -73,7 +71,7 @@
 #  ifdef KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51b03
+#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51b06
 #  endif
 #endif
 
@@ -82,7 +80,7 @@
 #endif
 
 #ifdef KDECORATIONS2_DEPRECATED
-#  define KDECORATIONS2_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KDECORATIONS2_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KDECORATIONS2_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
